package main

import (
	"fmt"

	"github.com/beego/beego/v2/server/web"
	"github.com/beego/beego/v2/server/web/context"
)

func main() {
	// 静态路由
	// 绑定函数，以 GET 方式请求 / 时，通过该匿名函数处理
	web.Get("/", func(ctx *context.Context) {
		// 用户数据获取
		name := ctx.Input.Query("name")
		ctx.Output.Context.WriteString(fmt.Sprint("get your name is ", name))
	})

	// Post 请求
	web.Post("/", func(ctx *context.Context) {
		name := ctx.Input.Query("name")
		ctx.Output.Context.WriteString(fmt.Sprint("post your name is ", name))
	})

	// 任意请求，相同方式时，是否生效与代码的顺序有关
	web.Any("/any/", func(ctx *context.Context) {
		ctx.Output.Context.WriteString(fmt.Sprintf("you actions is %s", ctx.Request.Method))
	})

	// 正则路由，URL中定义正则字符串匹配，示例匹配 /number/ 格式路由，并放入 :id 参数中
	//web.Get("/:id(^\\d+$)/", func(ctx *context.Context) {
	// ? 表示没有 id 也匹配
	web.Get("/?:id(^\\d+$)/", func(ctx *context.Context) {
		// 用户数据获取
		//id := ctx.Input.Query(":id")
		id := ctx.Input.Param(":id")
		ctx.Output.Context.WriteString(fmt.Sprint("number url id is ", id))
	})
	// 不区分类型
	web.Get("/any/:any/", func(ctx *context.Context) {
		// 用户数据获取
		any := ctx.Input.Query(":any")
		ctx.Output.Context.WriteString(fmt.Sprint("any url id is ", any))
	})
	// 类型获取 /file/abc /file/a/b/c
	web.Get("/file/*", func(ctx *context.Context) {
		// 通过 splat 获取没有名字的参数
		splat := ctx.Input.Param(":splat")
		ctx.Output.Context.WriteString(fmt.Sprintf("file %s", splat))
	})
	// /ext/a.txt
	web.Get("/ext/*.*", func(ctx *context.Context) {
		path := ctx.Input.Param(":path") // a
		ext := ctx.Input.Param(":ext")   // txt
		ctx.Output.Context.WriteString(fmt.Sprintf("file path %s, ext %s", path, ext))
	})
	web.Run()
}
